<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="nb_NO">
<context>
    <name>HiddenShortcutsDialog</name>
    <message>
        <location filename="../shortcuts.ui" line="14"/>
        <source>Hidden Shortcuts</source>
        <translation>Skjulte snarveier</translation>
    </message>
    <message>
        <location filename="../shortcuts.ui" line="20"/>
        <source>These hard coded shortcuts will be overridden if they are also assigned to other actions in Preferences → Shortcuts.</source>
        <translation>Disse hardkodede snarveiene vil bli overskrevet så snart de tildeles andre handlinger i Innstillinger → Snarveier.</translation>
    </message>
    <message>
        <location filename="../shortcuts.ui" line="34"/>
        <source>Shortcut</source>
        <translation>Snarvei</translation>
    </message>
    <message>
        <location filename="../shortcuts.ui" line="39"/>
        <source>Action</source>
        <translation>Handling</translation>
    </message>
    <message>
        <location filename="../shortcuts.ui" line="44"/>
        <source>Esc</source>
        <translation>Esc</translation>
    </message>
    <message>
        <location filename="../shortcuts.ui" line="47"/>
        <source>Close window or exit fullscreen mode</source>
        <translation>Lukk vindu eller avslutt fullskjermsvisning</translation>
    </message>
    <message>
        <location filename="../shortcuts.ui" line="52"/>
        <source>Right</source>
        <translation>Høyre</translation>
    </message>
    <message>
        <location filename="../shortcuts.ui" line="55"/>
        <location filename="../shortcuts.ui" line="63"/>
        <source>Next image</source>
        <translation>Neste bilde</translation>
    </message>
    <message>
        <location filename="../shortcuts.ui" line="60"/>
        <source>Space</source>
        <translation>Mellomrom</translation>
    </message>
    <message>
        <location filename="../shortcuts.ui" line="68"/>
        <source>End</source>
        <translation type="unfinished">End</translation>
    </message>
    <message>
        <location filename="../shortcuts.ui" line="71"/>
        <source>Last image</source>
        <translation>Siste bilde</translation>
    </message>
    <message>
        <location filename="../shortcuts.ui" line="76"/>
        <source>Left</source>
        <translation>Venstre</translation>
    </message>
    <message>
        <location filename="../shortcuts.ui" line="79"/>
        <location filename="../shortcuts.ui" line="87"/>
        <source>Previous image</source>
        <translation>Forrige bilde</translation>
    </message>
    <message>
        <location filename="../shortcuts.ui" line="84"/>
        <source>Backspace</source>
        <translation>Rettetast</translation>
    </message>
    <message>
        <location filename="../shortcuts.ui" line="92"/>
        <source>Home</source>
        <translation type="unfinished">Hjem</translation>
    </message>
    <message>
        <location filename="../shortcuts.ui" line="95"/>
        <source>First image</source>
        <translation>Første bilde</translation>
    </message>
</context>
<context>
    <name>LxImage::Application</name>
    <message>
        <location filename="../application.cpp" line="97"/>
        <source>Start in fullscreen (can be useful with tiling window managers)</source>
        <translation>Start i fullskjermsvisning (kan være nyttig med flisbaserte vindushåndterere)</translation>
    </message>
    <message>
        <location filename="../application.cpp" line="105"/>
        <source>Take a screenshot (deprecated, please use screengrab instead)</source>
        <translation>Utfør skjermavbildning (foreldet, bruk screengrab istedenfor)</translation>
    </message>
    <message>
        <location filename="../application.cpp" line="114"/>
        <source>DIR</source>
        <translation>MAPPE</translation>
    </message>
    <message>
        <location filename="../application.cpp" line="114"/>
        <source>Take a screenshot and save it to the directory without showing the GUI (deprecated, please use screengrab instead)</source>
        <translation>Utfør en skjermavbildning og lagre den til mappen uten å vise grensesnittet (foreldet, bruk screengrab istedenfor)</translation>
    </message>
    <message>
        <location filename="../application.cpp" line="120"/>
        <source>[FILE1, FILE2,...]</source>
        <translation></translation>
    </message>
</context>
<context>
    <name>LxImage::ImgBBUpload</name>
    <message>
        <location filename="../upload/imgbbupload.cpp" line="44"/>
        <source>unknown error response</source>
        <translation>Ukjent feilrespons</translation>
    </message>
</context>
<context>
    <name>LxImage::ImgurUpload</name>
    <message>
        <location filename="../upload/imgurupload.cpp" line="47"/>
        <source>unknown error response</source>
        <translation>Ukjent feilrespons</translation>
    </message>
</context>
<context>
    <name>LxImage::MainWindow</name>
    <message>
        <location filename="../mainwindow.cpp" line="300"/>
        <source>About</source>
        <translation>Om</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="302"/>
        <source>A simple and fast image viewer</source>
        <translation>En enkel og rask bildeviser</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="304"/>
        <source>Copyright (C) </source>
        <translation type="unfinished">Opphavsrett © </translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="306"/>
        <source>LXQt Project</source>
        <translation type="unfinished">LXQt-prosjektet</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="308"/>
        <source>Development: </source>
        <translation>Utvikling: </translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="310"/>
        <source>Author: </source>
        <translation>Utvikler: </translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="539"/>
        <source>Open File</source>
        <translation>Åpne fil</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="540"/>
        <location filename="../mainwindow.cpp" line="575"/>
        <source>Image files (%1)</source>
        <translation>Bildefiler (%1)</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="553"/>
        <source>Open directory</source>
        <translation>Åpne mappe</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="574"/>
        <source>Save File</source>
        <translation>Lagre fil</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="724"/>
        <location filename="../mainwindow.cpp" line="730"/>
        <location filename="../mainwindow.cpp" line="736"/>
        <location filename="../mainwindow.cpp" line="742"/>
        <location filename="../mainwindow.cpp" line="917"/>
        <source>%1/%2 Frames</source>
        <translation>%1/%2 sider</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="896"/>
        <source>[*]%1 (Loading...) - Image Viewer</source>
        <translation>[*]%1 (Laster inn...) - Bildeviser</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="902"/>
        <source>[*]%1 (Failed to Load) - Image Viewer</source>
        <translation>[*]%1 (Klarte ikke å laste inn) - Bildeviser</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="908"/>
        <source>[*]%1 (%2x%3) - Image Viewer</source>
        <translation>[*]%1 (%2x%3) - Bildeviser</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="980"/>
        <source>[*]Image Viewer</source>
        <translation>[*] Bildeviser</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="1397"/>
        <source>Thumbnails</source>
        <translation>Minibilder</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="1492"/>
        <source>EXIF Data</source>
        <translation>EXIF-data</translation>
    </message>
</context>
<context>
    <name>LxImage::MruMenu</name>
    <message>
        <location filename="../mrumenu.cpp" line="49"/>
        <source>&amp;Clear</source>
        <translation>&amp;Tøm</translation>
    </message>
</context>
<context>
    <name>LxImage::PreferencesDialog</name>
    <message>
        <location filename="../preferencesdialog.cpp" line="74"/>
        <source>Use a modifier key to clear a shortcut
in the editing mode.</source>
        <translation>Bruk en endringstast for å opprette en snarvei
i redigeringsmodus.</translation>
    </message>
    <message>
        <location filename="../preferencesdialog.cpp" line="215"/>
        <source>Bottom</source>
        <translation type="unfinished">Bunn</translation>
    </message>
    <message>
        <location filename="../preferencesdialog.cpp" line="216"/>
        <source>Top</source>
        <translation type="unfinished">Topp</translation>
    </message>
    <message>
        <location filename="../preferencesdialog.cpp" line="217"/>
        <source>Left</source>
        <translation>Venstre</translation>
    </message>
    <message>
        <location filename="../preferencesdialog.cpp" line="343"/>
        <source>&lt;b&gt;Warning: Ambiguous shortcut detected!&lt;/b&gt;</source>
        <translation>&lt;b&gt;Advarsel: Tvetydig snarvei oppdaget.&lt;/b&gt;</translation>
    </message>
    <message>
        <location filename="../preferencesdialog.cpp" line="360"/>
        <source>&lt;b&gt;Ambiguous shortcut not accepted.&lt;/b&gt;</source>
        <translation>&lt;b&gt;Tvetydig snarvei godtas ikke.&lt;/b&gt;</translation>
    </message>
</context>
<context>
    <name>LxImage::SaveImageJob</name>
    <message>
        <location filename="../saveimagejob.cpp" line="54"/>
        <source>Cannot save with this image format!</source>
        <translation>Kan ikke lagre i dette bildeformatet!</translation>
    </message>
</context>
<context>
    <name>LxImage::StatusBar</name>
    <message>
        <location filename="../statusbar.cpp" line="63"/>
        <source>Size:</source>
        <translation>Størrelse:</translation>
    </message>
    <message>
        <location filename="../statusbar.cpp" line="73"/>
        <source>Path:</source>
        <translation>Sti:</translation>
    </message>
</context>
<context>
    <name>LxImage::UploadDialog</name>
    <message>
        <location filename="../upload/uploaddialog.cpp" line="47"/>
        <source>Imgur</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../upload/uploaddialog.cpp" line="48"/>
        <source>ImgBB</source>
        <translation>ImgBB</translation>
    </message>
    <message>
        <location filename="../upload/uploaddialog.cpp" line="136"/>
        <source>Start</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../upload/uploaddialog.cpp" line="139"/>
        <source>Stop</source>
        <translation>Stopp</translation>
    </message>
    <message>
        <location filename="../upload/uploaddialog.cpp" line="142"/>
        <source>Close</source>
        <translation>Lukk</translation>
    </message>
    <message>
        <location filename="../upload/uploaddialog.cpp" line="149"/>
        <source>Error</source>
        <translation>Feil</translation>
    </message>
</context>
<context>
    <name>MainWindow</name>
    <message>
        <location filename="../mainwindow.ui" line="14"/>
        <source>Image Viewer</source>
        <translation>Bildeviser</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="234"/>
        <source>&amp;About</source>
        <translation>&amp;Om</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="214"/>
        <location filename="../mainwindow.ui" line="709"/>
        <source>Annotations Toolbar</source>
        <translation>Verktøylinje for merknader</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="67"/>
        <source>Open &amp;With...</source>
        <translation>Åpne &amp;med …</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="72"/>
        <source>&amp;Recent Files</source>
        <translation>&amp;Nylige filer</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="126"/>
        <source>Sorting</source>
        <translation>Sortering</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="239"/>
        <source>Hidden &amp;Shortcuts</source>
        <translation>Skjulte &amp;snarveier</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="248"/>
        <source>&amp;Open…</source>
        <translation>&amp;Åpne…</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="251"/>
        <source>Ctrl+O</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="260"/>
        <source>&amp;Reload File</source>
        <translation>&amp;Last inn fil på nytt</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="263"/>
        <source>Ctrl+R</source>
        <translation>Ctrl+R</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="272"/>
        <source>&amp;Save</source>
        <translation>&amp;Lagre</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="275"/>
        <source>Ctrl+S</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="284"/>
        <source>Save &amp;As</source>
        <translation>Lagre &amp;som</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="287"/>
        <source>Ctrl+A</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="296"/>
        <source>&amp;Close</source>
        <translation>&amp;Lukk</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="299"/>
        <source>Ctrl+W</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="308"/>
        <source>Zoom &amp;In</source>
        <translation>Zoom &amp;Inn</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="311"/>
        <source>Ctrl+=</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="320"/>
        <source>Zoom &amp;Out</source>
        <translation>Zoom &amp;Ut</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="323"/>
        <source>Ctrl+-</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="332"/>
        <source>&amp;Copy to Clipboard</source>
        <translation>&amp;Kopier til utklippstavlen</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="341"/>
        <location filename="../mainwindow.ui" line="344"/>
        <source>Next File</source>
        <translation>Neste fil</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="347"/>
        <source>PgDown</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="356"/>
        <location filename="../mainwindow.ui" line="359"/>
        <source>Previous File</source>
        <translation>Forrige fil</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="362"/>
        <source>PgUp</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="374"/>
        <source>Original Size</source>
        <translation>Original størrelse</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="377"/>
        <source>Ctrl+0</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="389"/>
        <source>&amp;Fit</source>
        <translation>&amp;Tilpass</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="398"/>
        <source>&amp;Rotate Clockwise</source>
        <translation>&amp;Roter med klokken</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="401"/>
        <source>R</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="410"/>
        <source>Rotate &amp;Counterclockwise</source>
        <translation>Roter &amp;mot klokken</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="413"/>
        <source>L</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="418"/>
        <source>P&amp;references</source>
        <translation>I&amp;nnstillinger</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="427"/>
        <source>&amp;Print</source>
        <translation>&amp;Skriv ut</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="430"/>
        <source>Ctrl+P</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="439"/>
        <source>First File</source>
        <translation>Første fil</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="442"/>
        <source>Home</source>
        <translation>Hjem</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="451"/>
        <source>Last File</source>
        <translation>Siste fil</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="454"/>
        <source>End</source>
        <translation>End</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="463"/>
        <source>&amp;New Window</source>
        <translation>&amp;Nytt vindu</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="466"/>
        <source>Ctrl+N</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="475"/>
        <source>Flip &amp;Horizontally</source>
        <translation>Speilvend &amp;horisontalt</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="478"/>
        <source>H</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="487"/>
        <source>Capture Screenshot</source>
        <translation>Ta skjermbilde</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="495"/>
        <source>F&amp;ull Screen</source>
        <translation>F&amp;ullskjerm</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="498"/>
        <source>F11</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="507"/>
        <source>Flip &amp;Vertically</source>
        <translation>Speilvend &amp;vertikalt</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="510"/>
        <source>V</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="519"/>
        <source>&amp;Paste from Clipboard</source>
        <translation>&amp;Lim inn fra utklippstavlen</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="531"/>
        <source>&amp;Slide Show</source>
        <translation>&amp;Lysbildeframvisning</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="540"/>
        <source>&amp;Delete</source>
        <translation>&amp;Slett</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="543"/>
        <source>Del</source>
        <translation>Del</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="551"/>
        <source>Show Thumbnails</source>
        <translation>Vis minibilder</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="554"/>
        <source>T</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="563"/>
        <source>File Properties</source>
        <translation>Filegenskaper</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="572"/>
        <source>Open &amp;Directory</source>
        <translation>Åpne &amp;mappe</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="575"/>
        <source>Ctrl+D</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="584"/>
        <source>Upload</source>
        <translation>Last opp</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="587"/>
        <source>Upload the image</source>
        <translation>Last opp bildet</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="590"/>
        <source>Ctrl+U</source>
        <translation>Ctrl+U</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="598"/>
        <source>Show EXIF Data</source>
        <translation>Vis EXIF-data</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="610"/>
        <source>No Tool</source>
        <translation>Intet verktøy</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="613"/>
        <source>Deselect all drawing tools</source>
        <translation>Fravelg alle tegneverktøy</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="625"/>
        <source>Draw Arrow</source>
        <translation>Tegn pil</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="628"/>
        <source>Draw an arrow</source>
        <translation>Tegn en pil</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="640"/>
        <source>Draw Rectangle</source>
        <translation>Tegn rektangel</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="643"/>
        <source>Draw a hollow rectangle</source>
        <translation>Tegn et rektangel uten fyll</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="655"/>
        <source>Draw Circle</source>
        <translation>Tegn sirkel</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="658"/>
        <source>Draw a hollow circle</source>
        <translation>Tegn sirkel uten fyll</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="670"/>
        <source>Draw Number</source>
        <translation>Tegn tall</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="673"/>
        <source>Draw incrementing numbers</source>
        <translation>Tegn tall i rekkefølge</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="681"/>
        <location filename="../mainwindow.ui" line="684"/>
        <source>Menubar</source>
        <translation>Menylinje</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="687"/>
        <source>Ctrl+M</source>
        <translation>Ctrl+M</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="695"/>
        <source>&amp;Main Toolbar</source>
        <translation>&amp;Hovedverktøylinje</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="698"/>
        <source>Main Toolbar</source>
        <translation>Hovedverktøylinje</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="706"/>
        <source>&amp;Annotations Toolbar</source>
        <translation>&amp;Verktøylinje for merknader</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="717"/>
        <location filename="../mainwindow.ui" line="720"/>
        <source>Show Outline</source>
        <translation>Vis omriss</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="723"/>
        <source>O</source>
        <translation>O</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="731"/>
        <source>Copy Pa&amp;th</source>
        <translation>Kopier &amp;sti</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="734"/>
        <source>Copy path</source>
        <translation>Kopier sti</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="742"/>
        <location filename="../mainwindow.ui" line="745"/>
        <source>Rename</source>
        <translation>Gi nytt navn</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="748"/>
        <source>F2</source>
        <translation>F2</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="757"/>
        <source>Resize</source>
        <translation>Endre størrelse</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="765"/>
        <source>&amp;By File Name</source>
        <translation>Etter fil&amp;navn</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="768"/>
        <source>By File Name</source>
        <translation>Etter filnavn</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="776"/>
        <source>By &amp;Modification Time</source>
        <translation>Etter &amp;endringstid</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="779"/>
        <source>By Modification Time</source>
        <translation>Etter endringstid</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="787"/>
        <source>By C&amp;reation Time</source>
        <translation>Etter &amp;opprettelsestid</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="790"/>
        <source>By Creation Time</source>
        <translation>Etter opprettelsestid</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="798"/>
        <source>By File &amp;Size</source>
        <translation>Etter fil&amp;størrelse</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="801"/>
        <source>By File Size</source>
        <translation>Etter filstørrelse</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="809"/>
        <source>By File &amp;Type</source>
        <translation>Etter fil&amp;type</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="812"/>
        <source>By File Type</source>
        <translation>Etter filtype</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="817"/>
        <source>Next Frame</source>
        <translation>Neste side</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="820"/>
        <source>Ctrl+Right</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="825"/>
        <source>Previous Frame</source>
        <translation>Forrige side</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="828"/>
        <source>Ctrl+Left</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="833"/>
        <source>First Frame</source>
        <translation>Første side</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="838"/>
        <source>Last Frame</source>
        <translation>Siste side</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="849"/>
        <source>Solid Background</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="63"/>
        <source>&amp;File</source>
        <translation>&amp;Fil</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="101"/>
        <source>&amp;Help</source>
        <translation>&amp;Hjelp</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="108"/>
        <source>Go</source>
        <translation>Gå</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="122"/>
        <source>&amp;View</source>
        <translation>&amp;Vis</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="155"/>
        <source>&amp;Edit</source>
        <translation>&amp;Rediger</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="179"/>
        <source>Toolbar</source>
        <translation>Verktøylinje</translation>
    </message>
</context>
<context>
    <name>PreferencesDialog</name>
    <message>
        <location filename="../preferencesdialog.ui" line="14"/>
        <source>Preferences</source>
        <translation>Innstillinger</translation>
    </message>
    <message>
        <location filename="../preferencesdialog.ui" line="33"/>
        <source>Icon theme:</source>
        <translation>Ikontema:</translation>
    </message>
    <message>
        <location filename="../preferencesdialog.ui" line="53"/>
        <source>Thumbnailer file size limit:</source>
        <translation>Filstørrelsesgrense for miniatyrbilder:</translation>
    </message>
    <message>
        <location filename="../preferencesdialog.ui" line="151"/>
        <source>Normal background color:</source>
        <translation>Normal bakgrunnsfarge:</translation>
    </message>
    <message>
        <location filename="../preferencesdialog.ui" line="165"/>
        <source>Fullscreen background color:</source>
        <translation>Fullskjerms bakgrunnsfarge:</translation>
    </message>
    <message>
        <location filename="../preferencesdialog.ui" line="43"/>
        <source>Maximum number of recent files:</source>
        <translation>Maksimalt antall nylige filer:</translation>
    </message>
    <message>
        <location filename="../preferencesdialog.ui" line="228"/>
        <source>Slide show interval (seconds):</source>
        <translation>Lysbildeframvisningstid (sekunder):</translation>
    </message>
    <message>
        <location filename="../preferencesdialog.ui" line="249"/>
        <source>Show image outline by default</source>
        <translation>Vis bildeomriss som standard</translation>
    </message>
    <message>
        <location filename="../preferencesdialog.ui" line="134"/>
        <source>Show annotations toolbar by default</source>
        <translation>Vis verktøylinje for merknader som standard</translation>
    </message>
    <message>
        <location filename="../preferencesdialog.ui" line="256"/>
        <source>Fit images when navigating</source>
        <translation>Tilpass billedstørrelse ved navigering</translation>
    </message>
    <message>
        <location filename="../preferencesdialog.ui" line="60"/>
        <source> MiB</source>
        <translation> MiB</translation>
    </message>
    <message>
        <location filename="../preferencesdialog.ui" line="76"/>
        <source>Thumbnail image dimensions:</source>
        <translation>Miniatyrbildedimensjoner:</translation>
    </message>
    <message>
        <location filename="../preferencesdialog.ui" line="86"/>
        <source>Use system Trash (and do not prompt)</source>
        <translation type="unfinished">Bruk systemets papirkurv (uten å spørre)</translation>
    </message>
    <message>
        <location filename="../preferencesdialog.ui" line="94"/>
        <source>Window</source>
        <translation>Vindu</translation>
    </message>
    <message>
        <location filename="../preferencesdialog.ui" line="103"/>
        <source>Show thumbnails dock by default</source>
        <translation>Vis minibilde-dokk som standard</translation>
    </message>
    <message>
        <location filename="../preferencesdialog.ui" line="113"/>
        <source>Show Exif data dock by default</source>
        <translation type="unfinished">Vis Exif-datadokk som forvalg</translation>
    </message>
    <message>
        <location filename="../preferencesdialog.ui" line="120"/>
        <source>Show menubar by default</source>
        <translation>Vis menylinje som standard</translation>
    </message>
    <message>
        <location filename="../preferencesdialog.ui" line="127"/>
        <source>Show main toolbar by default</source>
        <translation>Vis hovedverktøylinje som standard</translation>
    </message>
    <message>
        <location filename="../preferencesdialog.ui" line="142"/>
        <source>Image</source>
        <translation>Bilde</translation>
    </message>
    <message>
        <location filename="../preferencesdialog.ui" line="179"/>
        <location filename="../preferencesdialog.ui" line="190"/>
        <source>May work only with images which have valid color spaces.
Reload current image to see the effect.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../preferencesdialog.ui" line="183"/>
        <source>Color space:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../preferencesdialog.ui" line="195"/>
        <source>None</source>
        <translation>Ingen</translation>
    </message>
    <message>
        <location filename="../preferencesdialog.ui" line="200"/>
        <source>sRGB (supported by most monitors)</source>
        <translation>sRGB (støttes av de fleste skjermer)</translation>
    </message>
    <message>
        <location filename="../preferencesdialog.ui" line="205"/>
        <source>Linear sRGB (linear gamma)</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../preferencesdialog.ui" line="210"/>
        <source>Adobe RGB</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../preferencesdialog.ui" line="215"/>
        <source>DisplayP3 (wide-gamut screens)</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../preferencesdialog.ui" line="220"/>
        <source>ProPhotoRgb</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../preferencesdialog.ui" line="242"/>
        <source>Solid background by default</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../preferencesdialog.ui" line="263"/>
        <source>Smooth images on zooming</source>
        <translation type="unfinished">Myk opp bilder ved forstørrelse</translation>
    </message>
    <message>
        <location filename="../preferencesdialog.ui" line="271"/>
        <source>Shortcuts</source>
        <translation>Snarveier</translation>
    </message>
    <message>
        <location filename="../preferencesdialog.ui" line="290"/>
        <source>Action</source>
        <translation>Handling</translation>
    </message>
    <message>
        <location filename="../preferencesdialog.ui" line="295"/>
        <source>Shortcut</source>
        <translation>Snarvei</translation>
    </message>
    <message>
        <location filename="../preferencesdialog.ui" line="303"/>
        <source>Default</source>
        <translation>Forvalg</translation>
    </message>
    <message>
        <location filename="../preferencesdialog.ui" line="24"/>
        <source>General</source>
        <translation>Generelt</translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <location filename="../mainwindow.cpp" line="1098"/>
        <source>Error</source>
        <translation>Feil</translation>
    </message>
</context>
<context>
    <name>ResizeImageDialog</name>
    <message>
        <location filename="../resizeimagedialog.ui" line="14"/>
        <source>Resize Image</source>
        <translation>Endre bildestørrelse</translation>
    </message>
    <message>
        <location filename="../resizeimagedialog.ui" line="26"/>
        <source>Width</source>
        <translation>Bredde</translation>
    </message>
    <message>
        <location filename="../resizeimagedialog.ui" line="33"/>
        <source>Height</source>
        <translation>Høyde</translation>
    </message>
    <message>
        <location filename="../resizeimagedialog.ui" line="40"/>
        <source>Current size:</source>
        <translation>Nåværende størrelse:</translation>
    </message>
    <message>
        <location filename="../resizeimagedialog.ui" line="80"/>
        <source>New size:</source>
        <translation>Ny størrelse:</translation>
    </message>
    <message>
        <location filename="../resizeimagedialog.ui" line="93"/>
        <location filename="../resizeimagedialog.ui" line="116"/>
        <source> px</source>
        <translation> px</translation>
    </message>
    <message>
        <location filename="../resizeimagedialog.ui" line="129"/>
        <location filename="../resizeimagedialog.ui" line="158"/>
        <source> %</source>
        <translation> %</translation>
    </message>
    <message>
        <location filename="../resizeimagedialog.ui" line="174"/>
        <source>Keep aspect ratio</source>
        <translation>Behold sideforhold</translation>
    </message>
</context>
<context>
    <name>ScreenshotDialog</name>
    <message>
        <location filename="../screenshotdialog.ui" line="14"/>
        <source>Screenshot</source>
        <translation>Skjermbilde</translation>
    </message>
    <message>
        <location filename="../screenshotdialog.ui" line="27"/>
        <source>Take a screenshot</source>
        <translation>Ta et skjermbilde</translation>
    </message>
    <message>
        <location filename="../screenshotdialog.ui" line="34"/>
        <source>Region</source>
        <translation>Område</translation>
    </message>
    <message>
        <location filename="../screenshotdialog.ui" line="40"/>
        <source>Whole screen</source>
        <translation>Hele skjermen</translation>
    </message>
    <message>
        <location filename="../screenshotdialog.ui" line="50"/>
        <source>Current window only</source>
        <translation>Kun nåværende vindu</translation>
    </message>
    <message>
        <location filename="../screenshotdialog.ui" line="57"/>
        <source>Capture an area of the screen</source>
        <translation>Ta bilde av et område på skjermen</translation>
    </message>
    <message>
        <location filename="../screenshotdialog.ui" line="67"/>
        <source>Include mouse cursor</source>
        <translation>Inkluder muspekeren</translation>
    </message>
    <message>
        <location filename="../screenshotdialog.ui" line="74"/>
        <source> sec</source>
        <translation> sek</translation>
    </message>
    <message>
        <location filename="../screenshotdialog.ui" line="91"/>
        <source>Delay:</source>
        <translation>Forsinkelse:</translation>
    </message>
    <message>
        <location filename="../screenshotdialog.ui" line="101"/>
        <source>Include window title and frame</source>
        <translation>Inkluder vindustittel og ramme</translation>
    </message>
</context>
<context>
    <name>UploadDialog</name>
    <message>
        <location filename="../upload/uploaddialog.ui" line="14"/>
        <source>Upload</source>
        <translation>Last opp</translation>
    </message>
    <message>
        <location filename="../upload/uploaddialog.ui" line="39"/>
        <source>Copy</source>
        <translation>Kopier</translation>
    </message>
</context>
</TS>
